@@ -1,8 +1,8 @@
+from django.conf import settings
 from django.http import HttpResponse
 
 from dynamicresponse.emitters import JSONEmitter
 
-
 class JsonResponse(HttpResponse):
     """
     Provides a JSON response to a client, performing automatic serialization.
@@ -16,4 +16,4 @@ class JsonResponse(HttpResponse):
         status_code = kwargs.get('status', 200)
         
         # Return response with correct payload/type
-        super(JsonResponse, self).__init__(content, mimetype='application/json', status=status_code)
+        super(JsonResponse, self).__init__(content, content_type='application/json; charset=%s' % settings.DEFAULT_CHARSET)
